==> jc-1.4.0.tar.gz: javax/imageio/ImageTypeSpecifier.h <==
// public class javax.imageio.ImageTypeSpecifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 55863a2f3756ba17 javax_imageio_ImageTypeSpecifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageTypeSpecifier_H_
#define _JC_javax_imageio_ImageTypeSpecifier_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_RenderedImage$object;
struct _jc_java_awt_image_SampleModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageTypeSpecifier$sub_refs	_jc_javax_imageio_ImageTypeSpecifier$sub_refs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs	_jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$refs	_jc_javax_imageio_ImageTypeSpecifier$refs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$nonrefs	_jc_javax_imageio_ImageTypeSpecifier$nonrefs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$object	_jc_javax_imageio_ImageTypeSpecifier$object;

typedef const struct _jc_javax_imageio_ImageTypeSpecifier$vmethods	_jc_javax_imageio_ImageTypeSpecifier$vmethods;
typedef const struct _jc_javax_imageio_ImageTypeSpecifier$vtable	_jc_javax_imageio_ImageTypeSpecifier$vtable;
typedef const struct _jc_javax_imageio_ImageTypeSpecifier$vtype	_jc_javax_imageio_ImageTypeSpecifier$vtype;

// Constructors
extern void _jc_javax_imageio_ImageTypeSpecifier$method$_init$e5f483a2b7900d4d(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_SampleModel$object *);
extern void _jc_javax_imageio_ImageTypeSpecifier$method$_init$afcbb9a4598c745f(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_awt_image_ColorModel$object *_jc_javax_imageio_ImageTypeSpecifier$method$getColorModel$c0873fe840f235f1(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
extern jint _jc_javax_imageio_ImageTypeSpecifier$method$getNumBands$9c3b5af1c14f471e(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
extern jint _jc_javax_imageio_ImageTypeSpecifier$method$getNumComponents$61e8905d7801e54e(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
extern struct _jc_java_awt_image_SampleModel$object *_jc_javax_imageio_ImageTypeSpecifier$method$getSampleModel$40b86377916a6dc8(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getColorModel$c0873fe840f235f1;
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getNumBands$9c3b5af1c14f471e;
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getNumComponents$61e8905d7801e54e;
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getSampleModel$40b86377916a6dc8;

// Virtual methods structure
struct _jc_javax_imageio_ImageTypeSpecifier$vmethods {
	struct _jc_java_awt_image_ColorModel$object	*(*getColorModel$c0873fe840f235f1)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
	jint	(*getNumBands$9c3b5af1c14f471e)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
	jint	(*getNumComponents$61e8905d7801e54e)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
	struct _jc_java_awt_image_SampleModel$object	*(*getSampleModel$40b86377916a6dc8)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
};

// Vtable
struct _jc_javax_imageio_ImageTypeSpecifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageTypeSpecifier$vmethods	javax_imageio_ImageTypeSpecifier;
};

// Vtype
struct _jc_javax_imageio_ImageTypeSpecifier$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageTypeSpecifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageTypeSpecifier$sub_refs {
	struct _jc_java_awt_image_ColorModel$object	*colorModel;
	struct _jc_java_awt_image_SampleModel$object	*sampleModel;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageTypeSpecifier$refs {
    _jc_javax_imageio_ImageTypeSpecifier$sub_refs	javax_imageio_ImageTypeSpecifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageTypeSpecifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs	javax_imageio_ImageTypeSpecifier;
};

// Object instance structure
struct _jc_javax_imageio_ImageTypeSpecifier$object {
	_jc_javax_imageio_ImageTypeSpecifier$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageTypeSpecifier$vtype	*vtype;
	_jc_javax_imageio_ImageTypeSpecifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageTypeSpecifier$vtype _jc_javax_imageio_ImageTypeSpecifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageTypeSpecifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageTypeSpecifier$class_object;

#endif	/* _JC_javax_imageio_ImageTypeSpecifier_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/ImageTypeSpecifier.h <==
// public class javax.imageio.ImageTypeSpecifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 55863a2f3756ba17 javax_imageio_ImageTypeSpecifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageTypeSpecifier_H_
#define _JC_javax_imageio_ImageTypeSpecifier_H_

// Forward structure declarations
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_awt_image_RenderedImage$object;
struct _jc_java_awt_image_SampleModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageTypeSpecifier$sub_refs	_jc_javax_imageio_ImageTypeSpecifier$sub_refs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs	_jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$refs	_jc_javax_imageio_ImageTypeSpecifier$refs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$nonrefs	_jc_javax_imageio_ImageTypeSpecifier$nonrefs;
typedef struct _jc_javax_imageio_ImageTypeSpecifier$object	_jc_javax_imageio_ImageTypeSpecifier$object;

typedef const struct _jc_javax_imageio_ImageTypeSpecifier$vmethods	_jc_javax_imageio_ImageTypeSpecifier$vmethods;
typedef const struct _jc_javax_imageio_ImageTypeSpecifier$vtable	_jc_javax_imageio_ImageTypeSpecifier$vtable;
typedef const struct _jc_javax_imageio_ImageTypeSpecifier$vtype	_jc_javax_imageio_ImageTypeSpecifier$vtype;

// Constructors
extern void _jc_javax_imageio_ImageTypeSpecifier$method$_init$e5f483a2b7900d4d(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_SampleModel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_ImageTypeSpecifier$method$_init$afcbb9a4598c745f(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_image_ColorModel$object *_jc_javax_imageio_ImageTypeSpecifier$method$getColorModel$c0873fe840f235f1(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_ImageTypeSpecifier$method$getNumBands$9c3b5af1c14f471e(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_imageio_ImageTypeSpecifier$method$getNumComponents$61e8905d7801e54e(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_image_SampleModel$object *_jc_javax_imageio_ImageTypeSpecifier$method$getSampleModel$40b86377916a6dc8(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getColorModel$c0873fe840f235f1;
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getNumBands$9c3b5af1c14f471e;
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getNumComponents$61e8905d7801e54e;
extern _jc_method _jc_javax_imageio_ImageTypeSpecifier$method_info$getSampleModel$40b86377916a6dc8;

// Virtual methods structure
struct _jc_javax_imageio_ImageTypeSpecifier$vmethods {
	struct _jc_java_awt_image_ColorModel$object	*(*getColorModel$c0873fe840f235f1)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
	jint	(*getNumBands$9c3b5af1c14f471e)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
	jint	(*getNumComponents$61e8905d7801e54e)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_image_SampleModel$object	*(*getSampleModel$40b86377916a6dc8)(_jc_env *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_ImageTypeSpecifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageTypeSpecifier$vmethods	javax_imageio_ImageTypeSpecifier;
};

// Vtype
struct _jc_javax_imageio_ImageTypeSpecifier$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageTypeSpecifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageTypeSpecifier$sub_refs {
	struct _jc_java_awt_image_ColorModel$object	*colorModel;
	struct _jc_java_awt_image_SampleModel$object	*sampleModel;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageTypeSpecifier$refs {
    _jc_javax_imageio_ImageTypeSpecifier$sub_refs	javax_imageio_ImageTypeSpecifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageTypeSpecifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageTypeSpecifier$sub_nonrefs	javax_imageio_ImageTypeSpecifier;
};

// Object instance structure
struct _jc_javax_imageio_ImageTypeSpecifier$object {
	_jc_javax_imageio_ImageTypeSpecifier$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageTypeSpecifier$vtype	*vtype;
	_jc_javax_imageio_ImageTypeSpecifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageTypeSpecifier$vtype _jc_javax_imageio_ImageTypeSpecifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageTypeSpecifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageTypeSpecifier$class_object;

#endif	/* _JC_javax_imageio_ImageTypeSpecifier_H_ */
